==> JVPC-0.93.zip: JVPC-0.93/vga/Player.java <==
package jvpc.vga;

// Player in universe
public class Player {
  public final static int UNKNOWN = 0;
  public final static int ENEMY = 1;
  public final static int NEUTRAL = 2;
  public final static int ALLY = 3;
  public final static int SELF = 4;
  int shipStatus = ENEMY;	// gives color to be used to visiualize player
  int planetStatus = ENEMY;	// i.e. shipStatus determines color of ships of this player
  int minefieldStatus = ENEMY;

  String longname;
  String shortname;
  String adjective;

  Universe universe;
  int player;
  int race = -1;		// TODO: use field

  /**
   * Sets all status to @param newstatus
   */
  public void setStatus(int newstatus) {
    setShipStatus(true, newstatus);
    setPlanetStatus(true, newstatus);
    setMinefieldStatus(true, newstatus);
  }

  /**
   * Sets ship status to @param newstatus.
   * When override is false, it only succeeds when
   * @param newstatus > current status.
   */
  public void setShipStatus(boolean override, int newstatus) {
    if (override || (newstatus > shipStatus))
      shipStatus = newstatus;
  }

  public int getShipStatus() {
    return shipStatus;
  }

  public void setMinefieldStatus(boolean override, int newstatus) {
    if (override || (newstatus > minefieldStatus))
      minefieldStatus = newstatus;
  }

  public int getMinefieldStatus() {
    return minefieldStatus;
  }

  public void setPlanetStatus(boolean override, int newstatus) {
    if (override || (newstatus > planetStatus))
      planetStatus = newstatus;
  }

  public int getPlanetStatus() {
    return planetStatus;
  }

  public String getLongname() {
    return longname;
  }

  public String getShortname() {
    return shortname;
  }

  public String getAdjective() {
    return adjective;
  }

  public Player(Universe u,int player) {
    universe = u;
    this.player = player;
    longname = universe.getGame().racelong[player]; // Ugly, FIXME
    shortname = universe.getGame().raceshort[player];
    adjective = universe.getGame().raceadj[player];
  }

  /**
   * Return race.
   * See class Race.
   */
  public int getRace() {
    return race;
  }

  public void setRace(int newrace) {
    race = newrace;
  }

}

==> JVPC-0.94.zip: JVPC-0.94/vga/Player.java <==
package jvpc.vga;

// Player in universe
public class Player {
  public final static int UNKNOWN = 0;
  public final static int ENEMY = 1;
  public final static int NEUTRAL = 2;
  public final static int ALLY = 3;
  public final static int SELF = 4;
  int shipStatus = ENEMY;	// gives color to be used to visiualize player
  int planetStatus = ENEMY;	// i.e. shipStatus determines color of ships of this player
  int minefieldStatus = ENEMY;

  /* String longname;
  String shortname;
  String adjective;
  */

  Universe universe;
  int player;
  int race = -1;		// TODO: use field

  /**
   * Sets all status to @param newstatus
   */
  public void setStatus(int newstatus) {
    setShipStatus(true, newstatus);
    setPlanetStatus(true, newstatus);
    setMinefieldStatus(true, newstatus);
  }

  /**
   * Sets ship status to @param newstatus.
   * When override is false, it only succeeds when
   * @param newstatus > current status.
   */
  public void setShipStatus(boolean override, int newstatus) {
    if (override || (newstatus > shipStatus))
      shipStatus = newstatus;
  }

  public int getShipStatus() {
    return shipStatus;
  }

  public void setMinefieldStatus(boolean override, int newstatus) {
    if (override || (newstatus > minefieldStatus))
      minefieldStatus = newstatus;
  }

  public int getMinefieldStatus() {
    return minefieldStatus;
  }

  public void setPlanetStatus(boolean override, int newstatus) {
    if (override || (newstatus > planetStatus))
      planetStatus = newstatus;
  }

  public int getPlanetStatus() {
    return planetStatus;
  }

  public String getLongname() {
    // return longname;
    return universe.getGame().racelong[player];
  }

  public String getShortname() {
    // return shortname;
    return universe.getGame().raceshort[player];
  }

  public String getAdjective() {
    // return adjective;
    return universe.getGame().raceadj[player];
  }

  public Player(Universe u,int player) {
    universe = u;
    this.player = player;
    /* longname = universe.getGame().racelong[player]; // Ugly, FIXME
    shortname = universe.getGame().raceshort[player];
    adjective = universe.getGame().raceadj[player];
    */
  }

  /**
   * Return race.
   * See class Race.
   */
  public int getRace() {
    return race;
  }

  public void setRace(int newrace) {
    race = newrace;
  }

}
